Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8)

Unified Diff: LayoutTests/imported/csswg-test/css-shapes-1/shape-outside/values/support/parsing-utils.js

Issue 1274643002: CSSStyleDeclaraction returns empty string (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Updated failing tests Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: LayoutTests/imported/csswg-test/css-shapes-1/shape-outside/values/support/parsing-utils.js
diff --git a/LayoutTests/imported/csswg-test/css-shapes-1/shape-outside/values/support/parsing-utils.js b/LayoutTests/imported/csswg-test/css-shapes-1/shape-outside/values/support/parsing-utils.js
index beea4958ce8adf15ac3a446aea6bd96a361d48a7..d33371c3acb803d570a2f4730f9550db079061ab 100644
--- a/LayoutTests/imported/csswg-test/css-shapes-1/shape-outside/values/support/parsing-utils.js
+++ b/LayoutTests/imported/csswg-test/css-shapes-1/shape-outside/values/support/parsing-utils.js
@@ -98,12 +98,12 @@ function buildTestCases(testCases, testType) {
var results = [];
// If test_type isn't specified, test inline style
- var type = typeof testType == 'undefined' ? 'invalid': testType;
+ var type = typeof testType == 'undefined' ? 'empty_string': testType;
testCases.forEach(function(test) {
oneTestCase = [];
// name - annotated by type (inline vs. computed)
if ( test.hasOwnProperty('name') ) {
oneTestCase.push(test['name'] +' - '+ type);
} else {
@@ -115,8 +115,8 @@ function buildTestCases(testCases, testType) {
oneTestCase.push(test['actual'])
// expected
- if( type.indexOf('invalid') != -1 ){
- oneTestCase.push(null)
+ if( type.indexOf('empty_string') != -1 ){
+ oneTestCase.push('')
} else if( type == 'inline' ) {
oneTestCase.push(test['expected_inline']);
} else if( type == 'computed' ){
@@ -174,7 +174,7 @@ function buildPositionTests(shape, valid, type, units) {
testCase = new Array();
testCase.push(testValue + ' is invalid');
testCase.push(testValue);
- testCase.push(null);
+ testCase.push("");
results.push(testCase);
});
}
@@ -98,12 +98,12 @@ function buildTestCases(testCases, testType) {
testCases.forEach(function(test) {
oneTestCase = [];
- // name - annotated by type (inline vs. computed)
+ // name - annotated by type (empty_string vs. computed)
if ( test.hasOwnProperty('name') ) {
oneTestCase.push(test['name'] +' - '+ type);

Powered by Google App Engine
This is Rietveld 408576698